==> core-1.30.0-sources.jar: software/amazon/awscdk/core/RemovalPolicyOptions.java <==
package software.amazon.awscdk.core;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-03-18T17:03:07.171Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.RemovalPolicyOptions")
@software.amazon.jsii.Jsii.Proxy(RemovalPolicyOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RemovalPolicyOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Apply the same deletion policy to the resource's "UpdateReplacePolicy".
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default java.lang.Boolean getApplyToUpdateReplacePolicy() {
        return null;
    }

    /**
     * The default policy to apply in case the removal policy is not defined.
     * <p>
     * Default: - Default value is resource specific. To determine the default value for a resoure,
     * please consult that specific resource's documentation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default software.amazon.awscdk.core.RemovalPolicy getDefaultValue() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.Boolean applyToUpdateReplacePolicy;
        private software.amazon.awscdk.core.RemovalPolicy defaultValue;

        /**
         * Sets the value of {@link RemovalPolicyOptions#getApplyToUpdateReplacePolicy}
         * @param applyToUpdateReplacePolicy Apply the same deletion policy to the resource's "UpdateReplacePolicy".
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applyToUpdateReplacePolicy(java.lang.Boolean applyToUpdateReplacePolicy) {
            this.applyToUpdateReplacePolicy = applyToUpdateReplacePolicy;
            return this;
        }

        /**
         * Sets the value of {@link RemovalPolicyOptions#getDefaultValue}
         * @param defaultValue The default policy to apply in case the removal policy is not defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultValue(software.amazon.awscdk.core.RemovalPolicy defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RemovalPolicyOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RemovalPolicyOptions build() {
            return new Jsii$Proxy(applyToUpdateReplacePolicy, defaultValue);
        }
    }

    /**
     * An implementation for {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RemovalPolicyOptions {
        private final java.lang.Boolean applyToUpdateReplacePolicy;
        private final software.amazon.awscdk.core.RemovalPolicy defaultValue;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applyToUpdateReplacePolicy = this.jsiiGet("applyToUpdateReplacePolicy", java.lang.Boolean.class);
            this.defaultValue = this.jsiiGet("default", software.amazon.awscdk.core.RemovalPolicy.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean applyToUpdateReplacePolicy, final software.amazon.awscdk.core.RemovalPolicy defaultValue) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applyToUpdateReplacePolicy = applyToUpdateReplacePolicy;
            this.defaultValue = defaultValue;
        }

        @Override
        public java.lang.Boolean getApplyToUpdateReplacePolicy() {
            return this.applyToUpdateReplacePolicy;
        }

        @Override
        public software.amazon.awscdk.core.RemovalPolicy getDefaultValue() {
            return this.defaultValue;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApplyToUpdateReplacePolicy() != null) {
                data.set("applyToUpdateReplacePolicy", om.valueToTree(this.getApplyToUpdateReplacePolicy()));
            }
            if (this.getDefaultValue() != null) {
                data.set("default", om.valueToTree(this.getDefaultValue()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.RemovalPolicyOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RemovalPolicyOptions.Jsii$Proxy that = (RemovalPolicyOptions.Jsii$Proxy) o;

            if (this.applyToUpdateReplacePolicy != null ? !this.applyToUpdateReplacePolicy.equals(that.applyToUpdateReplacePolicy) : that.applyToUpdateReplacePolicy != null) return false;
            return this.defaultValue != null ? this.defaultValue.equals(that.defaultValue) : that.defaultValue == null;
        }

        @Override
        public int hashCode() {
            int result = this.applyToUpdateReplacePolicy != null ? this.applyToUpdateReplacePolicy.hashCode() : 0;
            result = 31 * result + (this.defaultValue != null ? this.defaultValue.hashCode() : 0);
            return result;
        }
    }
}

==> core-1.31.0-sources.jar: software/amazon/awscdk/core/RemovalPolicyOptions.java <==
package software.amazon.awscdk.core;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.1.0 (build df55f5e)", date = "2020-03-24T17:01:25.455Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.RemovalPolicyOptions")
@software.amazon.jsii.Jsii.Proxy(RemovalPolicyOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RemovalPolicyOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Apply the same deletion policy to the resource's "UpdateReplacePolicy".
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getApplyToUpdateReplacePolicy() {
        return null;
    }

    /**
     * The default policy to apply in case the removal policy is not defined.
     * <p>
     * Default: - Default value is resource specific. To determine the default value for a resoure,
     * please consult that specific resource's documentation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.core.RemovalPolicy getDefaultValue() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.Boolean applyToUpdateReplacePolicy;
        private software.amazon.awscdk.core.RemovalPolicy defaultValue;

        /**
         * Sets the value of {@link RemovalPolicyOptions#getApplyToUpdateReplacePolicy}
         * @param applyToUpdateReplacePolicy Apply the same deletion policy to the resource's "UpdateReplacePolicy".
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applyToUpdateReplacePolicy(java.lang.Boolean applyToUpdateReplacePolicy) {
            this.applyToUpdateReplacePolicy = applyToUpdateReplacePolicy;
            return this;
        }

        /**
         * Sets the value of {@link RemovalPolicyOptions#getDefaultValue}
         * @param defaultValue The default policy to apply in case the removal policy is not defined.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultValue(software.amazon.awscdk.core.RemovalPolicy defaultValue) {
            this.defaultValue = defaultValue;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RemovalPolicyOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RemovalPolicyOptions build() {
            return new Jsii$Proxy(applyToUpdateReplacePolicy, defaultValue);
        }
    }

    /**
     * An implementation for {@link RemovalPolicyOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RemovalPolicyOptions {
        private final java.lang.Boolean applyToUpdateReplacePolicy;
        private final software.amazon.awscdk.core.RemovalPolicy defaultValue;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applyToUpdateReplacePolicy = this.jsiiGet("applyToUpdateReplacePolicy", java.lang.Boolean.class);
            this.defaultValue = this.jsiiGet("default", software.amazon.awscdk.core.RemovalPolicy.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Boolean applyToUpdateReplacePolicy, final software.amazon.awscdk.core.RemovalPolicy defaultValue) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applyToUpdateReplacePolicy = applyToUpdateReplacePolicy;
            this.defaultValue = defaultValue;
        }

        @Override
        public java.lang.Boolean getApplyToUpdateReplacePolicy() {
            return this.applyToUpdateReplacePolicy;
        }

        @Override
        public software.amazon.awscdk.core.RemovalPolicy getDefaultValue() {
            return this.defaultValue;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getApplyToUpdateReplacePolicy() != null) {
                data.set("applyToUpdateReplacePolicy", om.valueToTree(this.getApplyToUpdateReplacePolicy()));
            }
            if (this.getDefaultValue() != null) {
                data.set("default", om.valueToTree(this.getDefaultValue()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/core.RemovalPolicyOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RemovalPolicyOptions.Jsii$Proxy that = (RemovalPolicyOptions.Jsii$Proxy) o;

            if (this.applyToUpdateReplacePolicy != null ? !this.applyToUpdateReplacePolicy.equals(that.applyToUpdateReplacePolicy) : that.applyToUpdateReplacePolicy != null) return false;
            return this.defaultValue != null ? this.defaultValue.equals(that.defaultValue) : that.defaultValue == null;
        }

        @Override
        public int hashCode() {
            int result = this.applyToUpdateReplacePolicy != null ? this.applyToUpdateReplacePolicy.hashCode() : 0;
            result = 31 * result + (this.defaultValue != null ? this.defaultValue.hashCode() : 0);
            return result;
        }
    }
}
